@@ -68,19 +68,23 @@ def reVerSplitToPV(x):
             'PR':"",
             'PVR':""}.copy()
 
-def getPkgUses(fullpkg):
+def getPkgUses(fullpkg, version=None):
     """Get USE and IUSE from package"""
     category,slash,pkg = fullpkg.partition('/')
     pkgCategory = '/var/db/pkg/{0}'.format(category)
-    packages = filter(lambda x:x['PN'] == pkg,
-               map(reVerSplitToPV,
-               filter(lambda x:x,
-               map(lambda x:reVerSplit.search(x),
-               listDirectory(pkgCategory)))))
-    if not packages:
-        return None
-    usePath = path.join(pkgCategory,packages[-1]['PF'],"USE")
-    iusePath = path.join(pkgCategory,packages[-1]['PF'],"IUSE")
+    if version is None:
+        packages = filter(lambda x:x['PN'] == pkg,
+                   map(reVerSplitToPV,
+                   filter(lambda x:x,
+                   map(lambda x:reVerSplit.search(x),
+                   listDirectory(pkgCategory)))))
+        if not packages:
+            return None
+        usePath = path.join(pkgCategory,packages[-1]['PF'],"USE")
+        iusePath = path.join(pkgCategory,packages[-1]['PF'],"IUSE")
+    else:
+        usePath = path.join(pkgCategory, "%s-%s"%(pkg,version),"USE")
+        iusePath = path.join(pkgCategory, "%s-%s"%(pkg,version),"IUSE")
     iuse = readFile(iusePath).strip().split()
     use = readFile(usePath).strip().split()
     return (map(lambda x:x[1:] if x.startswith("+") else x,
